#include "ColumbusDialog.h"

class ColumbusDialogPrivate
{
public:
    ApplicationController *controller;
};

ColumbusDialog::ColumbusDialog(QWidget *parent)
    : Maemo5Dialog(parent)
{
    this->d = new ColumbusDialogPrivate;
}

ColumbusDialog::~ColumbusDialog()
{
    delete this->d;
}

ApplicationController* ColumbusDialog::controller() const
{
    return d->controller;
}

void ColumbusDialog::setController(ApplicationController *controller)
{
    d->controller = controller;
}
